SystemOrganization addCategory: #'Grease-Tests-Pharo-Core'!

!GRPackage class methodsFor: '*grease-tests-pharo-core' stamp: 'lr 2/17/2010 15:11'!
greaseTestsPharoCore
	^ self new
		name: 'Grease-Tests-Pharo-Core';
		description: 'Unit tests for the package Grease-Pharo-Core.';
		addDependency: 'Grease-Pharo-Core';
		addDependency: 'Grease-Tests-Core';
		url: #seasideUrl;
		yourself! !

!GRUtf8CodecTest methodsFor: '*grease-tests-pharo-core' stamp: 'dkh 11/13/2009 16:01'!
expectedFailures
	^#(testCodecUtf8ShortestForm)! !

TestCase subclass: #GRPharoCodecTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Grease-Tests-Pharo-Core'!

!GRPharoCodecTest methodsFor: 'testing' stamp: 'pmm 8/16/2010 00:24'!
testAllCodesIncludesIso88591
	self assert: (GRCodec allCodecs anySatisfy: [ :each |
		each name = 'iso-8859-1' ])! !

TestCase subclass: #GRPharoColorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Grease-Tests-Pharo-Core'!

!GRPharoColorTest methodsFor: 'testing' stamp: 'pmm 1/11/2009 15:18'!
expectedFailures
	^#( testFromStringThreeDigit )! !

!GRPharoColorTest methodsFor: 'testing' stamp: 'pmm 1/9/2009 19:07'!
testAllColors
	| toTest |
	toTest := #(
		16r000000 16r000001 16r000101 16r010101 16r010100 16r010000 16r001001 16r101001
		16r001122 16r334455 16r667788 16r99AABB 16rCCDDEE 16rFF0011
		16r123456 16r789ABC 16rDEFEDC
		16rFEFEEF 16rFEFEFF 16rFEFEFE 16rFFFEFE 16rFFFFFE 16rFFFFFF).
	toTest do: [:int | 
		| hex |
		hex := int printPaddedWith: $0 to: 6 base: 16.
		self assert: (Color fromString: hex) asHTMLColor asLowercase = ('#', hex) asLowercase ]! !

!GRPharoColorTest methodsFor: 'testing' stamp: 'MAD 8/29/2008 15:36'!
testColorAsHtmlColor
	"test for:
	Color >> #hex
	| aStream |
	aStream := (String new: 6) writeStream.
	aStream nextPutAll: (((self red * 255) asInteger printStringBase: 16)
		padded: #left to: 2 with: $0).
	aStream nextPutAll: (((self green * 255) asInteger printStringBase: 16)
		padded: #left to: 2 with: $0).
	aStream nextPutAll: (((self blue * 255) asInteger printStringBase: 16)
		padded: #left to: 2 with: $0).
	^ aStream contents

	Color >> #asHTMLColor
	^ '#', self hex"
	self assert: (#('#ffffff' '#FFFFFF' ) includes: Color white asHTMLColor).
	self assert: (Color black asHTMLColor = '#000000').
	self assert: (#('#ff0000' '#FF0000' ) includes: Color red asHTMLColor)! !

!GRPharoColorTest methodsFor: 'testing' stamp: 'pmm 11/20/2008 22:00'!
testFromSixDigit
	self assert: (Color fromString: 'ff0000') = Color red.
	self assert: (Color fromString: 'FF0000') = Color red.
	self assert: (Color fromString: '#ff0000') = Color red.
	self assert: (Color fromString: '#FF0000') = Color red
! !

!GRPharoColorTest methodsFor: 'testing' stamp: 'pmm 11/20/2008 22:01'!
testFromStringName
	self assert: (Color fromString: 'red') = Color red.
	self assert: (Color fromString: 'RED') = Color red.
	self assert: (Color fromString: '#red') = Color red.
	self assert: (Color fromString: '#RED') = Color red.
! !

!GRPharoColorTest methodsFor: 'testing' stamp: 'pmm 11/20/2008 22:01'!
testFromStringSixDigit
	self assert: (Color fromString: 'ff0000') = Color red.
	self assert: (Color fromString: 'FF0000') = Color red.
	self assert: (Color fromString: '#ff0000') = Color red.
	self assert: (Color fromString: '#FF0000') = Color red
! !

!GRPharoColorTest methodsFor: 'testing' stamp: 'pmm 11/20/2008 22:06'!
testFromStringThreeDigit
	self assert: (Color fromString: 'f00') = Color red.
	self assert: (Color fromString: 'F00') = Color red.
	self assert: (Color fromString: '#f00') = Color red.
	self assert: (Color fromString: '#F00') = Color red.! !

TestCase subclass: #GRPharoGenericCodecTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Grease-Tests-Pharo-Core'!

!GRPharoGenericCodecTest methodsFor: 'testing' stamp: 'pmm 8/16/2010 00:47'!
testNoAmbiguities
	#('utf-8' 'UTF-8' 'utf8') do: [ :each |
		self deny: (GRPharoGenericCodec supportsEncoding: each) ].
	GRPharoLatin1Codec supportedEncodingNames do: [ :each |
		self deny: (GRPharoGenericCodec supportsEncoding: each) ]! !

TestCase subclass: #GRPharoPlatformTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Grease-Tests-Pharo-Core'!

!GRPharoPlatformTest methodsFor: 'tests' stamp: 'jf 9/30/2009 00:19'!
testCompileIntoClassified
	| source protocol selectors selector |
	source := 'aMethod
	^ ''a result'''.
	protocol := 'a-protocol'.
	selector := #aMethod.
	GRPlatform current 
		compile: source
		into: self class
		classified: protocol.
	
	[ self assert: (self class selectors includes: selector).
	selectors := self class organization listAtCategoryNamed: protocol.
	self assert: selectors = (Array with: selector) ] ensure: [ self class removeSelectorSilently: selector ]! !

!GRPharoPlatformTest methodsFor: 'tests' stamp: 'jf 10/6/2008 14:37'!
testFullName
	self assert: Object fullName = 'Object'! !

!GRPharoPlatformTest methodsFor: 'tests' stamp: 'jf 9/30/2009 01:07'!
testGreaseIntegerOnCharacter
	| character |
	character := Character codePoint: 19982.
	self assert: character greaseInteger = 19982.
	character := Unicode value: 19982.
	self assert: character greaseInteger = 19982.
	LanguageEnvironment allSubclassesDo: 
		[ :each | 
		(each class selectors includes: #leadingChar) ifTrue: 
			[ "fuck me gently with a chainsaw"
			character := Character 
				leadingChar: each leadingChar
				code: 19982.
			self assert: character greaseInteger = 19982 ] ]! !

!GRPharoPlatformTest methodsFor: 'tests' stamp: 'jf 12/18/2009 12:29'!
testMessageSendValueWithPossibleArguments
	| send |
	send := MessageSend receiver: 1 selector: #+.
	self assert: (send valueWithPossibleArguments: (Array with: 2)) = 3.
	self assert: (send valueWithArguments: (Array with: 2)) = 3.
	self assert: (send value: 2) = 3.

	send := MessageSend receiver: false selector: #not.
	self assert: (send valueWithPossibleArguments: (Array with: 3)).
	
	send := MessageSend receiver: 1 selector: #+ arguments: #(2).
	self assert: (send valueWithPossibleArguments: (Array with: 4)) = 3.
	self assert: send value = 3.
	
	send := MessageSend receiver: Array selector: #with:with: arguments: #(1).
	self assert: (send valueWithPossibleArguments: (Array with: 2)) size = 2.

	send := MessageSend receiver: Array selector: #with:with:.
	self assert: (send value: 1 value: 2) size = 2.
	
	send := MessageSend 
		receiver: 1
		selector: #+.
	self assert: send argumentCount = 1.
	self assert: send arguments size = 0.
	self assert: send fixCallbackTemps == send.
	
	send := MessageSend 
		receiver: 1
		selector: #+
		argument: 2.
	self assert: send argumentCount isZero.
	self assert: send arguments size = 1.
	self assert: send fixCallbackTemps == send! !
